import os
import shutil
import tempfile
import unittest

from .. import util


class SemaphoreTest(unittest.TestCase):
    def setUp(self):
        self.test_dir = tempfile.mkdtemp()

    def tearDown(self):
        shutil.rmtree(self.test_dir)

    def test_semaphore_creates_file(self):
        test_path = os.path.join(self.test_dir, "test")
        with util.FileSemaphore(test_path):
            self.assertTrue(os.path.exists(test_path))

    def test_semaphore_cleans_up_afer_itself(self):
        test_path = os.path.join(self.test_dir, "test")
        with util.FileSemaphore(test_path):
            pass
        self.assertFalse(os.path.exists(test_path))

    def semaphore_raises_on_file_exists(self):
        test_path = os.path.join(self.test_dir, "test")
        util.touch(test_path)
        # self.assertRaises doesn't seem to work with context managers.
        with self.assertRaises(util.SemaphoreExistsError):
            with util.FileSemaphore(test_path):
                pass


class TouchTest(unittest.TestCase):
    def setUp(self):
        self.test_dir = tempfile.mkdtemp()

    def tearDown(self):
        shutil.rmtree(self.test_dir)

    def test_touch_creates_file(self):
        thefile = os.path.join(self.test_dir, "whatever")
        util.touch(thefile)
        self.assertTrue(os.path.exists(thefile))
